@@ -84,6 +84,20 @@ impl VisitMut for Fixer<'_> {
             BlockStmtOrExpr::Expr(ref mut e) if e.is_seq() => {
                 self.wrap(&mut **e);
             }
+
+            BlockStmtOrExpr::Expr(ref mut e) if e.is_assign() => match &**e {
+                Expr::Assign(assign) => match &assign.left {
+                    PatOrExpr::Pat(l) => match &**l {
+                        Pat::Ident(..) | Pat::Expr(..) => {}
+                        _ => {
+                            self.wrap(&mut **e);
+                        }
+                    },
+                    PatOrExpr::Expr(..) => {}
+                },
+                _ => {}
+            },
+
             _ => {}
         };
         self.ctx = old;
@@ -117,7 +131,11 @@ impl VisitMut for Fixer<'_> {
         self.ctx = old;
 
         match &*expr.arg {
-            Expr::Cond(..) | Expr::Assign(..) => self.wrap(&mut expr.arg),
+            Expr::Cond(..)
+            | Expr::Assign(..)
+            | Expr::Bin(..)
+            | Expr::Unary(..)
+            | Expr::Update(..) => self.wrap(&mut expr.arg),
             _ => {}
         }
     }
@@ -1382,4 +1400,18 @@ var store = global[SHARED] || (global[SHARED] = {});
         };
         "
     );
+
+    identical!(
+        issue_2155,
+        "
+        async function main() {
+            let promise;
+            await (promise || (promise = Promise.resolve('this is a string')));
+        }
+        "
+    );
+
+    identical!(issue_2163_1, "() => ({foo} = bar());");
+
+    identical!(issue_2163_2, "() => ([foo] = bar());");
 }
