@@ -301,6 +301,7 @@ mod tests {
     use super::*;
     use crate::pass::noop;
     use swc_ecma_visit::{as_folder, FoldWith};
+    use testing::DebugUsingDisplay;
 
     #[test]
     fn external_helper() {
@@ -341,8 +342,8 @@ swcHelpers._throw();",
                 println!(">>>>> Orig <<<<<\n{}", input);
                 println!(">>>>> Code <<<<<\n{}", actual_src);
                 assert_eq!(
-                    crate::tests::DebugUsingDisplay(&actual_src),
-                    crate::tests::DebugUsingDisplay(&expected_src)
+                    DebugUsingDisplay(&actual_src),
+                    DebugUsingDisplay(&expected_src)
                 );
                 Err(())
             })
