@@ -1,15 +1,13 @@
 use self::ops::{Operations, Operator};
-use crate::ext::MapWithMut;
-use crate::native::is_native;
-use crate::native::is_native_word;
-use crate::scope::IdentType;
-use crate::scope::ScopeKind;
+use crate::{
+    ext::MapWithMut,
+    native::{is_native, is_native_word},
+    scope::{IdentType, ScopeKind},
+};
 use fxhash::{FxHashMap, FxHashSet};
 use smallvec::{smallvec, SmallVec};
-use std::cell::RefCell;
-use std::collections::HashMap;
-use swc_atoms::js_word;
-use swc_atoms::JsWord;
+use std::{cell::RefCell, collections::HashMap};
+use swc_atoms::{js_word, JsWord};
 use swc_common::{chain, SyntaxContext};
 use swc_ecma_ast::*;
 use swc_ecma_utils::ident::IdentLike;
